@@ -46,6 +46,7 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.jsieve.commands;
 
 import java.util.ArrayList;
@@ -57,100 +58,50 @@ import org.apache.jsieve.SieveException;
 import org.apache.jsieve.TagArgument;
 import com.openexchange.jsieve.commands.test.ITestCommand;
 
+/**
+ * A {@link TestCommand} is used as part of a control command. It is used to
+ * specify whether or not the block of code given to the control command is
+ * executed.
+ *
+ * General supported tests: "address", "allof", "anyof", "exists", "false",
+ * "header", "not", "size", and "true"
+ *
+ * Need require "envelope"
+ * <ul>
+ * <li><code>address [ADDRESS-PART] [COMPARATOR] [MATCH-TYPE] &lt;header-list: string-list&gt; &lt;key-list: string-list&gt;</code></li>
+ * <li><code>envelope [COMPARATOR] [ADDRESS-PART] [MATCH-TYPE] &lt;envelope-part: string-list&gt; &lt;key-list: string-list&gt;</code></li>
+ * <li><code>[ADDRESS-PART] = ":localpart" / ":domain" / ":all"</code></li>
+ * <li><code>exists &lt;header-names: string-list&gt;</code></li>
+ * <li><code>false</code></li>
+ * <li><code>true</code></li>
+ * <li><code>not &lt;test&gt;</code></li>
+ * <li><code>size &lt;":over" / ":under"&gt; &lt;limit: number&gt;</code></li>
+ * <li><code>header [COMPARATOR] [MATCH-TYPE] &lt;header-names: string-list&gt; &lt;key-list: string-list&gt;</code></li>
+ * <li><code>allof &lt;tests: test-list&gt;</code> (logical AND)</li>
+ * <li><code>anyof &lt;tests: test-list&gt; </code> (logical OR)</code></li>
+ * <li><code>Match-types are ":is", ":contains", and ":matches"</code></li>
+ * </ul>
+ *
+ * @author <a href="mailto:dennis.sieben@open-xchange.com">Dennis Sieben</a>
+ * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
+ */
 public class TestCommand extends Command {
-    /*
-     * A test command is used as part of a control command. It is used to
-     * specify whether or not the block of code given to the control command is
-     * executed.
-     *
-     * General supported tests: "address", "allof", "anyof", "exists", "false",
-     * "header", "not", "size", and "true"
-     *
-     * Need require "envelope"
-     *
-     * address [ADDRESS-PART] [COMPARATOR] [MATCH-TYPE] <header-list:
-     * string-list> <key-list: string-list>
-     *
-     * envelope [COMPARATOR] [ADDRESS-PART] [MATCH-TYPE] <envelope-part:
-     * string-list> <key-list: string-list>
-     *
-     * [ADDRESS-PART] = ":localpart" / ":domain" / ":all"
-     *
-     * exists <header-names: string-list>
-     *
-     * false
-     *
-     * true
-     *
-     * not <test>
-     *
-     * size <":over" / ":under"> <limit: number>
-     *
-     * header [COMPARATOR] [MATCH-TYPE] <header-names: string-list> <key-list:
-     * string-list>
-     *
-     * allof <tests: test-list> logical AND
-     *
-     * anyof <tests: test-list> logical OR
-     *
-     * Match-types are ":is", ":contains", and ":matches"
-     *
-     */
 
-    // protected static class TagArgument {
-    // private String tag;
-    // private boolean require;
-    //
-    // public final String getTag() {
-    // return tag;
-    // }
-    //
-    // public final boolean isRequire() {
-    // return require;
-    // }
-    //
-    // public final void setTag(String tag) {
-    // this.tag = tag;
-    // }
-    //
-    // public final void setRequire(boolean require) {
-    // this.require = require;
-    // }
-    //
-    // public TagArgument(String tag, boolean require) {
-    // super();
-    // this.tag = tag;
-    // this.require = require;
-    // }
-    //
-    // @Override
-    // public boolean equals(Object obj) {
-    // if (obj instanceof String) {
-    // final String text = (String) obj;
-    // return this.tag.equals(text);
-    // } else if (obj instanceof TagArgument) {
-    // final TagArgument tagArgument = (TagArgument) obj;
-    // return tagArgument.tag.equals(tagArgument.tag) && (tagArgument.require ==
-    // tagArgument.require);
-    // }
-    // return false;
-    // }
-    // }
     public enum Commands implements ITestCommand {
-        ADDRESS("address", 2, Integer.MAX_VALUE, standardAddressPart(), standardComparators(), standardAddressMatchTypes(), standardJSONAddressMatchTypes(), null),
-        ENVELOPE("envelope", 2, Integer.MAX_VALUE, standardAddressPart(), standardComparators(), standardMatchTypes(), standardJSONMatchTypes(), "envelope"),
-//        EXITS("exists", 1, 1, null, null, null, null, null),
-        FALSE("false", 0, 0, null, null, null, null, null),
-        TRUE("true", 0, 0, null, null, null, null, null),
-        NOT("not", 0, 0, null, null, null, null, null),
-        SIZE("size", 1, 1, null, null, matchTypeSize(), standardJSONSizeMatchTypes(), null),
-        HEADER("header", 2, Integer.MAX_VALUE, standardAddressPart(), standardComparators(), standardMatchTypes(), standardJSONMatchTypes(), null),
-        ALLOF("allof", 0, 0, null, null, null, null, null),
-        ANYOF("anyof", 0, 0, null, null, null, null, null),
-        BODY("body", 1, 1, standardBodyPart(), null, standardMatchTypes(), standardJSONMatchTypes(), "body"),
+        ADDRESS("address", 2, Integer.MAX_VALUE, standardAddressPart(), standardComparators(), standardAddressMatchTypes(), standardJSONAddressMatchTypes(), null, null),
+        ENVELOPE("envelope", 2, Integer.MAX_VALUE, standardAddressPart(), standardComparators(), standardMatchTypes(), standardJSONMatchTypes(), "envelope", null),
+        //        EXITS("exists", 1, 1, null, null, null, null, null),
+        FALSE("false", 0, 0, null, null, null, null, null, null),
+        TRUE("true", 0, 0, null, null, null, null, null, null),
+        NOT("not", 0, 0, null, null, null, null, null, null),
+        SIZE("size", 1, 1, null, null, matchTypeSize(), standardJSONSizeMatchTypes(), null, null),
+        HEADER("header", 2, Integer.MAX_VALUE, standardAddressPart(), standardComparators(), standardMatchTypes(), standardJSONMatchTypes(), null, null),
+        ALLOF("allof", 0, 0, null, null, null, null, null, null),
+        ANYOF("anyof", 0, 0, null, null, null, null, null, null),
+        BODY("body", 1, 1, standardBodyPart(), null, standardMatchTypes(), standardJSONMatchTypes(), "body", null),
         //DATE("date", 3, null, null, date_match_types(), "date"),
-        CURRENTDATE("currentdate", 2, Integer.MAX_VALUE, null, null, dateMatchTypes(), dateJSONMatchTypes(), "date"),
-        HASFLAG("hasflag", 1, Integer.MAX_VALUE, null, standardComparators(), standardMatchTypes(), standardJSONMatchTypes(), null);
+        CURRENTDATE("currentdate", 2, Integer.MAX_VALUE, null, null, dateMatchTypes(), dateJSONMatchTypes(), "date", dateOtherArguments()),
+        HASFLAG("hasflag", 1, Integer.MAX_VALUE, null, standardComparators(), standardMatchTypes(), standardJSONMatchTypes(), null, null);
 
         private static Hashtable<String, String> matchTypeSize() {
             final Hashtable<String, String> match_type_size = new Hashtable<String, String>(2);
@@ -161,8 +112,8 @@ public class TestCommand extends Command {
 
         private static List<String[]> standardJSONSizeMatchTypes() {
             final List<String[]> standard_match_types = Collections.synchronizedList(new ArrayList<String[]>(2));
-            standard_match_types.add(new String[]{"", "over"});
-            standard_match_types.add(new String[]{"", "under"});
+            standard_match_types.add(new String[] { "", "over" });
+            standard_match_types.add(new String[] { "", "under" });
             return standard_match_types;
         }
 
@@ -215,10 +166,10 @@ public class TestCommand extends Command {
 
         private static List<String[]> standardJSONMatchTypes() {
             final List<String[]> standard_match_types = Collections.synchronizedList(new ArrayList<String[]>(4));
-            standard_match_types.add(new String[]{"regex", "regex"});
-            standard_match_types.add(new String[]{"", "is"});
-            standard_match_types.add(new String[]{"", "contains"});
-            standard_match_types.add(new String[]{"", "matches"});
+            standard_match_types.add(new String[] { "regex", "regex" });
+            standard_match_types.add(new String[] { "", "is" });
+            standard_match_types.add(new String[] { "", "contains" });
+            standard_match_types.add(new String[] { "", "matches" });
             return standard_match_types;
         }
 
@@ -231,13 +182,19 @@ public class TestCommand extends Command {
             return standard_match_types;
         }
 
+        private static Hashtable<String, String> dateOtherArguments() {
+            final Hashtable<String, String> standard_match_types = new Hashtable<String, String>(1);
+            standard_match_types.put(":zone", "");
+            return standard_match_types;
+        }
+
         private static List<String[]> dateJSONMatchTypes() {
             final List<String[]> standard_match_types = Collections.synchronizedList(new ArrayList<String[]>(2));
-            standard_match_types.add(new String[]{"relational", "ge"});
-            standard_match_types.add(new String[]{"relational", "le"});
-            standard_match_types.add(new String[]{"", "is"});
-            standard_match_types.add(new String[]{"", "contains"});
-            standard_match_types.add(new String[]{"", "matches"});
+            standard_match_types.add(new String[] { "relational", "ge" });
+            standard_match_types.add(new String[] { "relational", "le" });
+            standard_match_types.add(new String[] { "", "is" });
+            standard_match_types.add(new String[] { "", "contains" });
+            standard_match_types.add(new String[] { "", "matches" });
             return standard_match_types;
         }
 
@@ -281,6 +238,11 @@ public class TestCommand extends Command {
          */
         private Hashtable<String, String> matchTypes;
 
+        /**
+         * Defines additional allowed arguments
+         */
+        private Hashtable<String, String> otherArguments;
+
         /**
          * Needed for the resolution of the configuration parameters for JSON
          */
@@ -291,9 +253,7 @@ public class TestCommand extends Command {
          */
         private String required;
 
-
-
-        Commands(final String commandName, final int numberOfArguments, int maxNumberOfArguments, final Hashtable<String, String> address, final Hashtable<String, String> comparator, final Hashtable<String, String> matchTypes, List<String[]> jsonMatchTypes, final String required) {
+        Commands(final String commandName, final int numberOfArguments, int maxNumberOfArguments, final Hashtable<String, String> address, final Hashtable<String, String> comparator, final Hashtable<String, String> matchTypes, List<String[]> jsonMatchTypes, final String required, final Hashtable<String, String> otherArguments) {
             this.commandName = commandName;
             this.numberOfArguments = numberOfArguments;
             this.maxNumberOfArguments = maxNumberOfArguments;
@@ -302,6 +262,7 @@ public class TestCommand extends Command {
             this.matchTypes = matchTypes;
             this.jsonMatchTypes = jsonMatchTypes;
             this.required = required;
+            this.otherArguments = otherArguments;
         }
 
         @Override
@@ -324,6 +285,11 @@ public class TestCommand extends Command {
             return address;
         }
 
+        @Override
+        public final Hashtable<String, String> getOtherArguments() {
+            return otherArguments;
+        }
+
         @Override
         public final Hashtable<String, String> getComparator() {
             return comparator;
@@ -379,7 +345,6 @@ public class TestCommand extends Command {
 
     private final int indexOfComparator = -1;
 
-
     /**
      *
      */
@@ -418,25 +383,30 @@ public class TestCommand extends Command {
             if (tagArray.contains(":comparator")) {
                 throw new SieveException("Sieve comparators aren't supported by this implementation");
             }
-//            final Hashtable<String, String> comparator = this.command.getComparator();
-//            if (null != comparator) {
-//                final boolean comparatorrule = tagarray.remove(":comparator");
-//                if (comparatorrule) {
-//                    // The argument of the comparator is located one after the
-//                    // comparator tag itself
-//                    indexOfComparator = searchcomparator() + 1;
-//                    final Object object = this.arguments.get(indexOfComparator);
-//                    if (object instanceof ArrayList) {
-//                        final ArrayList<String> new_name = (ArrayList<String>) object;
-//                        final String comparatorarg = new_name.get(0);
-//                        if (!comparator.containsKey(comparatorarg)) {
-//                            throw new SieveException(comparatorarg + " is no valid comparator for " + this.command.getCommandname());
-//                        }
-//                    } else {
-//                        throw new SieveException(object + " is no valid comparator for " + this.command.getCommandname());
-//                    }
-//                }
-//            }
+
+            final Hashtable<String, String> otherArguments = this.command.getOtherArguments();
+            if (null != otherArguments) {
+                tagArray.removeAll(otherArguments.keySet());
+            }
+            //            final Hashtable<String, String> comparator = this.command.getComparator();
+            //            if (null != comparator) {
+            //                final boolean comparatorrule = tagarray.remove(":comparator");
+            //                if (comparatorrule) {
+            //                    // The argument of the comparator is located one after the
+            //                    // comparator tag itself
+            //                    indexOfComparator = searchcomparator() + 1;
+            //                    final Object object = this.arguments.get(indexOfComparator);
+            //                    if (object instanceof ArrayList) {
+            //                        final ArrayList<String> new_name = (ArrayList<String>) object;
+            //                        final String comparatorarg = new_name.get(0);
+            //                        if (!comparator.containsKey(comparatorarg)) {
+            //                            throw new SieveException(comparatorarg + " is no valid comparator for " + this.command.getCommandname());
+            //                        }
+            //                    } else {
+            //                        throw new SieveException(object + " is no valid comparator for " + this.command.getCommandname());
+            //                    }
+            //                }
+            //            }
             if (!tagArray.isEmpty()) {
                 throw new SieveException("One of the tagArguments: " + tagArray + " is not valid for " + this.command.getCommandName());
             }
