@@ -693,10 +693,20 @@ public final class SieveTextFilter {
         return false;
     }
 
-    private List<String> interweaving(final List<OwnType> noncommentedoutput, final List<OwnType> commentedoutput, final List<Rule> rules) {
+    /**
+     * Writes the {@link Rule}s as a multi-line {@link String}. The non commented and commented outputs contain
+     * all correctly parsed sieve scripts. The rules {@link List} contains all the {@link Rule}s (also the ones
+     * with syntax errors).
+     * 
+     * @param nonCommentedOutput The non commented rules
+     * @param commentedOutput The commented rules
+     * @param rules All the rules
+     * @return A {@link List} with all {@link Rule}s as string objects
+     */
+    private List<String> interweaving(final List<OwnType> nonCommentedOutput, final List<OwnType> commentedOutput, final List<Rule> rules) {
         final List<String> retval = new ArrayList<String>();
         retval.add(FIRST_LINE + (new Date()).toString());
-        for (final OwnType owntype : noncommentedoutput) {
+        for (final OwnType owntype : nonCommentedOutput) {
             final int linenumber = owntype.getLinenumber();
             final String string = owntype.getOutput().toString();
             final int size = retval.size();
@@ -705,7 +715,7 @@ public final class SieveTextFilter {
             }
             retval.addAll(stringToList(string));
         }
-        for (final OwnType owntype : commentedoutput) {
+        for (final OwnType owntype : commentedOutput) {
             int linenumber = owntype.getLinenumber() - 1;
             final String string = owntype.getOutput().toString();
             final int size = retval.size();
@@ -722,13 +732,23 @@ public final class SieveTextFilter {
 
         for (final Rule rule : rules) {
             final RuleComment ruleComment = rule.getRuleComment();
-            final String text = rule.getText();
+            String text = rule.getText();
             if (null != text) {
                 final int line = ruleComment.getLine();
                 final int size = retval.size();
                 if (line > size) {
                     fillup(retval, line - size);
                 }
+
+                // Retain the commented state
+                if (rule.isCommented()) {
+                    String[] split = text.split(CRLF);
+                    StringBuilder sb = new StringBuilder();
+                    for (String s : split) {
+                        sb.append(COMMENT_TAG).append(s).append(CRLF);
+                    }
+                    text = sb.toString();
+                }
                 final ArrayList<String> stringToList = stringToList(text);
                 removeEmptyLines(retval, line, stringToList.size());
                 retval.addAll(line, stringToList);
