@@ -49,26 +49,21 @@
 
 package com.openexchange.mailfilter.internal;
 
-import java.util.HashMap;
-import java.util.Map;
+import org.slf4j.Logger;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Interests;
 import com.openexchange.config.Reloadable;
+import com.openexchange.config.Reloadables;
 import com.openexchange.mailfilter.osgi.MailFilterActivator;
 
 /**
  * {@link MailFilterReloadable}
- * 
+ *
  * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
  * @since 7.6.0
  */
 public class MailFilterReloadable implements Reloadable {
 
-    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MailFilterReloadable.class);
-
-    private static final String CONFIGFILE = "mailfilter.properties";
-
-    private static final String[] PROPERTIES = new String[] { "all properties in file" };
-
     /**
      * Initializes a new {@link MailFilterReloadable}.
      */
@@ -76,28 +71,19 @@ public class MailFilterReloadable implements Reloadable {
         super();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.config.Reloadable#reloadConfiguration(com.openexchange.config.ConfigurationService)
-     */
     @Override
     public void reloadConfiguration(ConfigurationService configService) {
         try {
             MailFilterActivator.checkConfigfile();
         } catch (Exception e) {
-            LOG.error("Error reloading configuration for bundle com.openexchange.mail.filter: {}", e);
+            Logger logger = org.slf4j.LoggerFactory.getLogger(MailFilterReloadable.class);
+            logger.error("Error reloading configuration for bundle com.openexchange.mail.filter: {}", e);
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.config.Reloadable#getConfigfileNames()
-     */
     @Override
-    public Map<String, String[]> getConfigFileNames() {
-        Map<String, String[]> map = new HashMap<String, String[]>(1);
-        map.put(CONFIGFILE, PROPERTIES);
-        return map;
+    public Interests getInterests() {
+        return Reloadables.interestsForFiles("mailfilter.properties");
     }
 
 }
